@@ -7,7 +7,7 @@ use Exporter 'import';
 use ExtUtils::MakeMaker;
 use XS::Install::Payload;
 
-our $VERSION = '1.0.13';
+our $VERSION = '1.0.14';
 my $THIS_MODULE = 'XS::Install';
 
 our @EXPORT_OK = qw/write_makefile makemaker_args not_available/;
@@ -537,8 +537,8 @@ sub binary_module_version {
     return MM->parse_version($pm) || 0;
 }
 
-sub has_c      { return $_[0]->{C} && scalar(keys @{$_[0]->{C}}) ? 1 : 0 }
-sub has_object { return $_[0]->{OBJECT} && scalar(keys @{$_[0]->{OBJECT}}) ? 1 : 0 }
+sub has_c      { return $_[0]->{C} && scalar(@{$_[0]->{C}}) ? 1 : 0 }
+sub has_object { return $_[0]->{OBJECT} && scalar(@{$_[0]->{OBJECT}}) ? 1 : 0 }
 sub has_xs     { return $_[0]->{XS} && scalar(keys %{$_[0]->{XS}}) ? 1 : 0 }
 sub has_binary { return has_c($_[0]) || has_object($_[0]) || has_xs($_[0]) }
 
